@@ -40,7 +40,7 @@ use Cwd 'abs_path';
 use File::Path qw(make_path remove_tree);
 use File::stat;
 
-our $VERSION = "0.23";
+our $VERSION = "0.24";
 
 use App::LXC::Container::Data;
 use App::LXC::Container::Mounts;
@@ -867,7 +867,7 @@ sub _write_lxc_configuration($)
 		$mounts->mount_point($key, EMPTY);
 	    }
 	    else
-	    {   push @{$self->{empty}}, $key;   }
+	    {   push @{$self->{empty_files}}, $key;   }
 	}
 	elsif ($_ eq 'ignore')
 	{   $mounts->mount_point($key, IGNORE);   }
@@ -924,7 +924,7 @@ sub _write_lxc_configuration($)
 
     ################################
     # part 5 - create all empty files:
-    foreach (@{$self->{empty}})
+    foreach (@{$self->{empty_files}})
     {
 	$_ = $self->{root_fs} . '/' . $container . $_;
 	# As we just deleted the whole tree we can't create a test for a
